@@ -1,15 +1,15 @@
 import numpy as np
 from functools import lru_cache
 from scipy.special import factorial
-from numba import njit
 import spherical_functions as sf
+from .. import jit
 
 
 sqrt3 = np.sqrt(3)
 sqrt2 = np.sqrt(2)
 
 
-"""Algorithm for computing H, as given by arxiv:1403.7698
+r"""Algorithm for computing H, as given by arxiv:1403.7698
 
 dₗⁿᵐ = ϵₙ ϵ₋ₘ Hₗⁿᵐ, where
 
@@ -54,17 +54,17 @@ H^{m', m}_n(\beta) = (-1)^{m+m'} H^{m', m}_n(-\beta)
 """
 
 
-@njit
+@jit
 def wedge_size(ℓₘₐₓ):
     return (ℓₘₐₓ+1) * (ℓₘₐₓ+2) * (2*ℓₘₐₓ+3) // 6
 
-@njit
+@jit
 def wedge_index(ℓ, mp, m):
     """Index to "wedge" arrays
 
-    Here, it is assumed that only data with m≥0 and |m'|≤m are stored, and only corresponding values
-    are passed.  We also assume |m|≤ℓ and |m'|≤ℓ.  Neither of these are checked.  The wedge array
-    that this function indexes is ordered as
+    Here, it is assumed that only data with m≥|m'| are stored, and only corresponding values are
+    passed.  We also assume |m|≤ℓ and |m'|≤ℓ.  Neither of these are checked.  The wedge array that
+    this function indexes is ordered as
 
         [(n, mp, m) for n in range(n_max+1) for mp in range(-n, n+1) for m in range(abs(mp), n+1)]
 
@@ -83,9 +83,9 @@ def wedge_index(ℓ, mp, m):
         return (2*(ℓ)*(ℓ+1)*(ℓ+2) + 3*mp*(2*ℓ+mp+3) + 6*m) // 6
 
 
-@njit
+@jit
 def wedgeify_index(ℓ, mp, m):
-    """Convert general (ℓ, m′, m) index into index appropriate for H wedge
+    r"""Convert general (ℓ, m′, m) index into index appropriate for H wedge
 
     The wedge is stored as
 
@@ -127,7 +127,7 @@ def wedgeify_index(ℓ, mp, m):
             return [ℓ, mp, m]
 
 
-@njit
+@jit
 def sign(m):
     if m >= 0:
         return 1
@@ -135,7 +135,7 @@ def sign(m):
         return -1
 
 
-@njit
+@jit
 def nm_index(n, m):
     """Return flat index into arrray of [n, m] pairs.
     
@@ -145,7 +145,7 @@ def nm_index(n, m):
     return m + n * (n + 1)
 
 
-@njit
+@jit
 def nabsm_index(n, absm):
     """Return flat index into arrray of [n, abs(m)] pairs
     
@@ -155,7 +155,7 @@ def nabsm_index(n, absm):
     return absm + (n * (n + 1)) // 2
 
 
-@njit
+@jit
 def nmpm_index(n, mp, m):
     """Return flat index into arrray of [n, mp, m]
     
@@ -167,15 +167,15 @@ def nmpm_index(n, mp, m):
     return (((4 * n + 6) * n + 6 * mp + 5) * n + 3 * (m + mp)) // 3
 
 
-@njit
+@jit
 def _step_1(Hwedge):
     """If n=0 set H_{0}^{0,0}=1."""
     Hwedge[0, :] = 1.0
 
 
-@njit
+@jit
 def _step_2(g, h, n_max, Hwedge, Hextra, Hv, cosβ, sinβ):
-    """Compute values H^{0,m}_{n}(β)for m=0,...,n and H^{0,m}_{n+1}(β) for m=0,...,n+1 using Eq. (32):
+    r"""Compute values H^{0,m}_{n}(β)for m=0,...,n and H^{0,m}_{n+1}(β) for m=0,...,n+1 using Eq. (32):
         H^{0,m}_{n}(β) = (-1)^m \sqrt{(n-|m|)! / (n+|m|)!} P^{|m|}_{n}(cos β)
                        = (-1)^m (sin β)^m \hat{P}^{|m|}_{n}(cos β) / \sqrt{k (2n+1)}
 
@@ -246,9 +246,9 @@ def _step_2(g, h, n_max, Hwedge, Hextra, Hv, cosβ, sinβ):
     Hv[nm_index(1, 0), :] = Hwedge[wedge_index(1, 0, 1)]
 
 
-@njit
+@jit
 def _step_3(a, b, n_max, Hwedge, Hextra, cosβ, sinβ):
-    """Use relation (41) to compute H^{1,m}_{n}(β) for m=1,...,n.  Using symmetry and shift of the
+    r"""Use relation (41) to compute H^{1,m}_{n}(β) for m=1,...,n.  Using symmetry and shift of the
     indices this relation can be written as
         b^{0}_{n+1} H^{1, m}_{n} =   \frac{b^{−m−1}_{n+1} (1−cosβ)}{2} H^{0, m+1}_{n+1}
                                    − \frac{b^{ m−1}_{n+1} (1+cosβ)}{2} H^{0, m−1}_{n+1}
@@ -280,7 +280,7 @@ def _step_3(a, b, n_max, Hwedge, Hextra, cosβ, sinβ):
                 )
 
 
-@njit
+@jit
 def _step_4(d, n_max, Hwedge, Hv):
     """Recursively compute H^{m'+1, m}_{n}(β) for m'=1,...,n−1, m=m',...,n using relation (50) resolved
     with respect to H^{m'+1, m}_{n}:
@@ -328,7 +328,7 @@ def _step_4(d, n_max, Hwedge, Hv):
                     )
 
 
-@njit
+@jit
 def _step_5(d, n_max, Hwedge, Hv):
     """Recursively compute H^{m'−1, m}_{n}(β) for m'=−1,...,−n+1, m=−m',...,n using relation (50)
     resolved with respect to H^{m'−1, m}_{n}:
@@ -392,6 +392,50 @@ def _step_5(d, n_max, Hwedge, Hv):
 
 class HCalculator(object):
     def __init__(self, n_max):
+        r"""Object to repeatedly calculate Wigner H values
+
+        The H matrix is related to Wigner's d matrix as given by arxiv:1403.7698 according to
+
+        dₗⁿᵐ = ϵₙ ϵ₋ₘ Hₗⁿᵐ, where
+
+               ⎧ 1 for k≤0
+          ϵₖ = ⎨
+               ⎩ (-1)ᵏ for k>0
+
+        This object has various advantageous features compared to the d matrix.  It obeys these
+        symmetry relations:
+
+            H^{m', m}_n(\beta) = H^{m, m'}_n(\beta)
+            H^{m', m}_n(\beta) = H^{-m', -m}_n(\beta)
+            H^{m', m}_n(\beta) = (-1)^{n+m+m'} H^{-m', m}_n(\pi - \beta)
+            H^{m', m}_n(\beta) = (-1)^{m+m'} H^{m', m}_n(-\beta)
+
+        In particular the simplicity of the first two of these relations implies that we only need
+        to compute one fourth of the total number of elements.  There is also a very accurate and
+        efficient recursion method to compute these values.
+
+        Create this object using the largest value of `n` (also commonly denoted `j` or `ℓ`) you
+        expect to need, optionally create the `workspace` for a given shape of cosβ using that method,
+        and then call this object for a given value or array of cosβ values.
+
+        The returned object is a series of "wedges" of the matrix, for the various values of `n`,
+        comprising just a quarter of the elements of the full matrix; all remaining elements are
+        determined by the first two symmetries above.  This wedge has an initial dimension
+        representing a multi-index for (ℓ, mp, m) values, while following dimensions are just the
+        same as cosβ.  Any required value may be obtained with `wedge_index(*wedgeify_index(ℓ, mp,
+        m))`.  The inner call translates a general index into the equivalent index lying inside the
+        wedge, while the outer call translates that corrected (ℓ, mp, m) tuple into a linear index
+        into the array.
+
+        Example Usage
+        =============
+
+        hcalc = HCalculator(n_max)
+        workspace = hcalc.workspace(cosβ)  # Note that cosβ can be an array of many values
+        # Possibly loop over many values of cosβ here
+        wedge = hcalc(cosβ, sinβ, workspace)
+
+        """
         self.n_max = int(n_max)
         if self.n_max < 0:
             raise ValueError('Nonsensical value for n_max = {0}'.format(self.n_max))
@@ -415,8 +459,9 @@ class HCalculator(object):
         ):
             raise ValueError("Found a non-finite value inside this object")
 
-    def workspace(self, cosβ):
+    def workspace(self, cosβ=1.0):
         """Return a new workspace sized for cosβ."""
+        cosβ = np.asarray(cosβ, dtype=float)
         return np.zeros((self.wedge_size+(self.n_max+1)**2+self.n_max+2,) + cosβ.shape, dtype=float)
 
     def __call__(self, cosβ, sinβ=None, workspace=None):
